@@ -6,5 +6,6 @@ class Reader:
     def __init__(self):
         pass
 
-    def read(self, file_path: Union[str, Path], *args, **kwargs) -> Any:
+    @staticmethod
+    def read(file_path: Union[str, Path], *args, **kwargs) -> Any:
         raise NotImplementedError
