@@ -5,5 +5,6 @@ from nlp_dataset_readers.common.reader import Reader
 
 
 class WicReader(Reader):
-    def read(self, file_path: Union[str, Path], *args, **kwargs) -> Any:
+    @staticmethod
+    def read(file_path: Union[str, Path], *args, **kwargs) -> Any:
         raise NotImplementedError
